@@ -3,8 +3,8 @@ from abc import ABC, abstractmethod
 
 import pygame
 
-from pi_touch_gui.colors import WHITE, BLACK, MEDIUM_GRAY
-from raspberrypi_ts import TS_PRESS, TS_RELEASE, TS_MOVE
+from .colors import WHITE, BLACK, MEDIUM_GRAY
+from multitouch.raspberrypi_ts import TS_PRESS, TS_RELEASE, TS_MOVE
 
 FONT_NAME = None
 
